@@ -10,10 +10,13 @@ LOG = logging.getLogger(__name__)
 
 
 @app.callback()
-def callback():
+def callback(debug: bool = False):
     """
     melter - Identifies which cases that should be analyzed again
     """
+    if debug:
+        typer.echo("DEBUG logging enabled")
+        logging.basicConfig(level=logging.DEBUG)
 
 
 @app.command()
