@@ -1,5 +1,9 @@
+import json
 import logging
 
+from melter.triggers import get_cases_that_need_new_analysis
+from melter.utils import run_command
+
 
 LOG = logging.getLogger(__name__)
 
@@ -9,8 +13,7 @@ def check_load_on_cluster(cases: list[str]) -> list[str]:
     Adjust the number of cases to start based
     on computational resources available
     """
-    cases_to_start = cases[0]
-    return [cases_to_start]
+    return [cases[0]]
 
 
 def start_jobs(cases: list[str]) -> None:
@@ -22,19 +25,17 @@ def start_jobs(cases: list[str]) -> None:
         LOG.info("Starting analysis for %s" % case)
 
 
-def get_cases_that_need_new_analysis(monitored_cases: list[str]) -> list[str]:
-    """
-    Find cases that qualify for a new
-    analysis among the monitored cases
-    """
-    return ["justhusky"]
+# from bson.json_util import loads
 
 
-def get_monitored_cases() -> list[str]:
+def get_monitored_cases() -> dict:
     """
     Return a list of cases that are monitored
     """
-    return ["justhusky", "coollamb"]
+    output_cli_call: str = run_command(
+        ["scout", "export", "cases", "--json", "--rerun-monitor"]
+    )
+    return json.loads(output_cli_call)
 
 
 def run_workflow() -> None:
@@ -46,11 +47,11 @@ def run_workflow() -> None:
     - Start the analyses
     """
     LOG.info("Requesting cases marked for monitoring in scout")
-    monitored_cases: list[str] = get_monitored_cases()
+    monitored_cases: dict = get_monitored_cases()
 
     LOG.info("Identifying cases which need a new analysis")
     cases_that_need_new_analysis: list[str] = get_cases_that_need_new_analysis(
-        monitored_cases=monitored_cases
+        cases=monitored_cases
     )
 
     LOG.info("Starting analyses")
